#
# spec file for package yast2-s390
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-s390
Version:        4.6.6
Release:        150600.1.1
Group:          System/YaST
License:        GPL-2.0-only
Summary:        YaST2 - S/390 Specific Features Configuration
URL:            https://github.com/yast/yast-s390/

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  update-desktop-files
BuildRequires:  yast2
BuildRequires:  yast2-devtools
BuildRequires:  yast2-ruby-bindings >= 3.1.7
BuildRequires:  rubygem(%rb_default_ruby_abi:rspec)
BuildRequires:  rubygem(%rb_default_ruby_abi:yast-rake)
# Y2Storage::Inhibitors
BuildRequires:  yast2-storage-ng >= 4.0.175
Requires:       s390-tools
Requires:       yast2
Requires:       yast2-ruby-bindings >= 3.1.7
Requires:       yast2-storage-ng >= 4.0.175

Supplements:    yast2-storage-ng
Supplements:    autoyast(xpram:zfcp:dasd)

ExclusiveArch:  s390 s390x

%description
This package contains the YaST component for configuration of
S/390-specific features.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%yast_metainfo

%files
%{yast_yncludedir}
%{yast_clientdir}
%{yast_libdir}
%{yast_moduledir}
%{yast_scrconfdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_schemadir}
%doc %{yast_docdir}
%license COPYING

%changelog
* Wed Mar  6 2024 jreidinger@suse.com
- Replace 'mkinitrd' with dracut (bsc#1220995)
- 4.6.6
* Tue Dec 12 2023 maier@linux.ibm.com
- onpanic: add support for multipathed zfcp-attached SCSI disks
  (bsc#1020336, also related to bsc#1216257).
- 4.6.5
* Fri Sep  1 2023 jreidinger@suse.com
- Branch package for SP6 (bsc#1208913)
* Wed May 10 2023 shundhammer@suse.com
- Prevent crash when the user closes the DASD context menu
  without action (bsc#1211213)
- Graceful handling of missing actions in the DASD context menu:
  just log an error, don't crash
- 4.5.3
* Thu Dec 22 2022 kanderssen@suse.com
- Fix hash vs keyword arguments in RSpec expectations (bsc#1204871)
- 4.5.2
* Thu Apr 21 2022 shundhammer@suse.com
- Don't call 'mkinitrd' in the inst-sys (bsc#1197632)
- 4.5.1
* Wed Apr  6 2022 lslezak@suse.cz
- Bump version to 4.5.0 (bsc#1198109)
* Mon Feb 28 2022 kanderssen@suse.com
- Fix format of unformatted disks after activation (bsc#1196559).
- 4.4.5
* Thu Feb 10 2022 kanderssen@suse.com
- Fix DasdSummary requirement (bsc#1195753)
- 4.4.4
* Tue Feb  1 2022 kanderssen@suse.com
- Related to jsc#SLE-20225
  - Do not limit the number of disks formatted in parallel
  - New format dialog introduced
- 4.4.3
* Fri Oct 22 2021 mvidner@suse.com
- Fix device filtering to follow major.minor semantic (jsc#SLE-17782)
- 4.4.2
* Thu Jun 24 2021 snwint@suse.com
- do not activate DASD devices after formatting (bsc#1187012)
- 4.4.1
* Tue Apr 20 2021 lslezak@suse.cz
- 4.4.0 (bsc#1185510)
* Tue Feb 23 2021 jreidinger@suse.com
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893, bsc#1182624).
- 4.3.3
* Tue Sep  8 2020 schubi@suse.de
- Using ":" in the autoyast(...) supplements (bsc#1146494).
- 4.3.2
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(xpram,zfcp,dasd) into the
  spec file in order to install this packages if the section has
  been defined in the AY configuration file (bsc#1146494).
- 4.3.1
* Tue May 12 2020 jreidinger@localhost
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.0
* Tue Mar 31 2020 igonzalezsosa@suse.com
- Do not try to activate DASD and zFCP devices that are already
  active (bsc#1163149). Related to jsc#SLE-7396.
- 4.2.5
* Mon Mar 23 2020 igonzalezsosa@suse.com
- Properly identify zFCP devices (bsc#1158443).
- 4.2.4
* Wed Dec 11 2019 schubi@suse.de
- Activating dumpconf: Ask the user to deactivate active kdump
  because they are conflicting each other (jsc#SLE-7749).
- 4.2.3
* Fri Jul 19 2019 aschnell@suse.com
- handle setting diag mode on active DASDs (part of bsc#1134927)
- 4.2.2
* Tue Jul 16 2019 aschnell@suse.com
- sort DASDs by channel ID (part of bsc#1134927)
- 4.2.1
* Fri Jun  7 2019 hellcp@mailbox.org
- Use new schema of desktop files (boo#1084864)
- Clean up spec
- Rename desktop files
- 4.2.0
* Wed Apr  3 2019 snwint@suse.com
- adjust zfcp "auto LUN scan" message (bsc#1068281)
- do not show "auto LUN scan" hint during auto install (bsc#1104021)
- 4.1.1
* Tue Feb 26 2019 jlopez@suse.com
- Version bump (bsc#1124009)
- 4.1.0
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Fri Sep 21 2018 dgonzalez@suse.com
- Avoid hanging YaST when try to deactivate a DASD in use
  (bsc#1091797)
- 4.0.5
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Tue May  8 2018 aschnell@suse.com
- disable mdadm auto assemble during DASD dialog (bsc#1089645)
- 4.0.4
* Tue Mar 20 2018 jreidinger@suse.com
- Improve error reporting and logging when underlying scripts
  failed for DASD (bsc#1070265)
- Allow to format ECKD DASD disk only (bsc#1070265)
- 4.0.3
* Mon Feb  5 2018 aschnell@suse.com
- added supplements for yast2-storage-ng (bsc#1070423)
- 4.0.2
* Tue Dec 12 2017 ancor@suse.com
- Clients used during upgrade now rely on yast-storage-ng
  instead of the old yast2-storage (bsc#1066538).
- 4.0.1
* Wed Nov  8 2017 aschnell@suse.com
- fixed call of dasdview (bsc#1067265)
- 4.0.0
* Wed May 31 2017 lslezak@suse.cz
- Fixed internal error displayed in the "dump" dialog (bsc#1040944)
- 3.2.2
* Mon Apr 24 2017 lslezak@suse.cz
- Skip the ZFCP controller warning when running in zKVM
  (bsc#1014178)
- Code cleanup: use Rubocop, support code coverage, move test data
  to YAML files, removed empty "agents/" subdir
- 3.2.1
* Mon Dec 19 2016 schubi@suse.de
- AutoYaST: Do not call DASD:Write twice (bnc#1014696).
- 3.2.0
* Mon Jun 20 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- 3.1.28
* Fri Jan 15 2016 schubi@suse.de
- DASD fix in formatting disks which have not been defined by
  AutoYaST. (bnc#959946)
- 3.1.27
* Wed Oct 28 2015 schubi@suse.de
- Reverting fix of version 3.1.24:
  - - added zfcp_disk_configure
  - - added wwpn and lun parameter while adding new devices
  - - removing delete option
  (bnc#951547, bnc#928574)
- 3.1.26
* Mon Aug 10 2015 ancor@suse.com
- Brings back accidentally removed 'ok' button to the zFCP dialog
  (bnc#940816)
- 3.1.25
* Wed Jul 22 2015 schubi@suse.de
- Fixes in ZFCP
  - - Do not use the zfcp_disk_configure call anymore.
  - - Removing wwpn and lun parameter while adding new devices.
  - - Removing delete option.
  - - bnc#928574
- 3.1.24
* Thu Jul  2 2015 schubi@suse.de
- Formating DASD: taking the device name instead of the map entry.
  (bnc#936112)
- 3.1.23
* Wed May 27 2015 schubi@suse.de
- dasd: Evaluating device name of channel (needed for format call).
  (bnc#928388)
- 3.1.22
* Thu Dec 18 2014 locilka@suse.com
- Command-line cleanup
- 3.1.21
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
- 3.1.20
* Wed Oct 22 2014 lslezak@suse.cz
- removed unnecessary BuildRequires
- 3.1.19
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.18
* Wed Jul 23 2014 aschnell@suse.de
- omit asking for parallel formatting if only one DASD is
  formatted (see bnc#888090)
- 3.1.17
* Thu Jul 17 2014 schubi@suse.de
- Autoyast export:  Exporting active DASD only
  (bnc#887407)
- 3.1.16
* Wed May 21 2014 jsrain@suse.cz
- corrected channel filter validation (bnc#874904)
- 3.1.15
* Wed May 14 2014 jreidinger@suse.com
- adapt to new bootloader API for grub2 (bnc#869608)
- 3.1.14
* Mon Apr 28 2014 jsrain@suse.cz
- adjusted the default filter for channels (bnc#874904)
- 3.1.13
* Tue Apr 22 2014 mpost@suse.com
- Changed the code that creates the dasdfmt command to use
  variables for the request size (-r) and the "cylinders per
  hashmark" value (-m)
- Adapted the progress bar for formatting DASD to match what is
  specified on the dasdfmt command.
- Set the values of both -r and -m to the new default value of 10
  that came in with s390-tools 1.24.1.
- 3.1.12
* Mon Mar 31 2014 thardeck@suse.com
- pass along group changes properly in IUCV module (bnc#870891)
- reset group cache before adding new ones
- 3.1.11
* Fri Mar 28 2014 jsrain@suse.cz
- re-activate DASD disks after formating (bnc#867267)
  (patch by Arvin)
- 3.1.10
* Wed Mar 19 2014 aschnell@suse.de
- do not execute zipl after DASD or zFCP configuration (bnc#869123)
- 3.1.9
* Fri Feb 28 2014 thardeck@suse.com
- fixed iucvterminal-server behavior on inital start
- 3.1.8
* Fri Feb 28 2014 thardeck@suse.com
- readded SCR agent files for iucvterminal-server module
- 3.1.7
* Thu Feb 27 2014 thardeck@suse.de
- fixed iucvterminal module to work with systemd (fate#314946)
- 3.1.6
* Wed Feb 12 2014 aschnell@suse.de
- fixed DASD probing (bnc#860398)
- 3.1.5
* Wed Feb  5 2014 jsrain@suse.cz
- enhanced unformatted disks handling during activation
  (fate#313403)
- fixed typos
- 3.1.4
* Fri Jan 31 2014 aschnell@suse.de
- fixed initialisation during installation (bnc#853929)
- 3.1.3
* Thu Jan 23 2014 jsrain@suse.cz
- enhanced handling of large amount of disks (fate#313402,
  fate#313403, fate#315984)
- 3.1.2
* Mon Dec  9 2013 jreidinger@suse.com
- add COPYING to fix building
- 3.1.1
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Mon Apr 15 2013 aschnell@suse.de
- reread storage after zFCP configuration (bnc#814953)
* Thu Mar 14 2013 aschnell@suse.de
- removed non-functioning button to not write label during DASD
  formatting (bnc#808275)
- reread storage after DASD configuration (bnc#808695)
- 2.22.2
* Tue Apr 10 2012 aschnell@suse.de
- changed license to GPL-2.0
* Thu Apr  5 2012 aschnell@suse.de
- added context menu to DASD module
- allow to change diag and format setting for DASDs in config mode
- do not show partition info for unformatted DASDs
* Wed Feb 22 2012 aschnell@suse.de
- make ZFCP module work with AutoYaST editor
* Wed Feb 15 2012 aschnell@suse.de
- make DASD module work with AutoYaST editor
* Fri Feb 10 2012 aschnell@suse.de
- use multiselection table in main DASD dialog
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Nov 22 2011 thardeck@suse.com
- fixed wrong Yast categories for IUCV terminal modules (fate#310723)
- fixed disabling of the IUCV input field in the ncurses dialog (fate#310723)
- check z/VM ids against username specification to prevent umlauts
* Fri Nov 18 2011 aschnell@suse.de
- merged proofread texts
- 2.22.0
* Mon Oct 31 2011 thardeck@suse.com
- fixed iucvterminal* module typos (bnc#723425)
* Wed Oct 26 2011 thardeck@suse.com
- fixed POSIX regex expressions
* Mon Oct 24 2011 thardeck@suse.com
- fixed some help texts (bnc#724622)
* Thu Oct 13 2011 aschnell@suse.de
- fixed fix for bnc#591603
* Wed Oct 12 2011 thardeck@suse.com
- added comments to help text
- replaced regex ASCII classes with POSIX
* Mon Oct 10 2011 thardeck@suse.com
- fixed translation (bnc#722447)
- removed workaround for (bnc#718089)
* Wed Sep  7 2011 thardeck@suse.com
- added IUCV Terminal module
- added IUCV Terminal Server module
* Mon Aug 29 2011 thardeck@suse.com
- updated onpanic dialog to allow 8 vmcmd commands and a total of 128 chars
- updated the help texts of the onpanic and dump modules
- removed X-KDE-RootOnly=true entry for both modules (bnc#681249)
* Tue Aug  9 2011 thardeck@novell.com
- extended dump module to support dasd multi-volume dump devices (fate#304024)
- added onpanic module - a fronted for dumpconf
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Fri Jul 22 2011 aschnell@suse.de
- fixed diag mode setting (bnc #591037)
* Tue Jun 21 2011 aschnell@suse.de
- use ButtonBox for correct button order (bnc #701269)
* Fri May 13 2011 aschnell@suse.de
- allow to configure zFCP tapes (fate #311718)
- 2.21.1
* Thu May  5 2011 aschnell@suse.de
- set exclusive architecture to s390 and s390x (bnc #690511)
- 2.21.0
* Tue Feb 15 2011 jsrain@suse.cz
- added time-out when asking about formatting a disk during
  AutoInstallation (bnc#668317)
* Thu Oct 21 2010 mzugec@suse.cz
- DASD: if possible, use device by-path in AY Export (bnc#591603)
- 2.19.5
* Wed Aug 18 2010 mzugec@suse.cz
- fixed typo (bnc#631743)
- 2.19.4
* Tue Feb  2 2010 mzugec@suse.cz
- DASD: support for additional dasd_configure ret codes (bnc#561876)
- 2.19.3
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Mon Dec 21 2009 mzugec@suse.cz
- dasd: activation non-formated devices (bnc#446998)
- 2.19.2
* Tue Dec  1 2009 mzugec@suse.cz
- fixed desktop files (bnc#559343)
- 2.19.1
* Mon Nov 30 2009 mzugec@suse.cz
- dasd: activation non-formated devices (bnc#446998)
- 2.19.0
* Thu Nov 12 2009 mzugec@suse.cz
- zfcp: fixed devices list filter (bnc#538313)
- 2.18.8
* Thu Nov  5 2009 mzugec@suse.cz
- dasd: display DIAG mode (bnc#551268)
- 2.18.7
* Wed Oct 21 2009 mzugec@suse.cz
- dump help option (bnc#531592)
* Wed Oct 21 2009 mzugec@suse.cz
- dasd help option (bnc#531590)
* Wed Oct 21 2009 mzugec@suse.cz
- zfcp help option (bnc#531594)
- 2.18.6
* Mon Oct 19 2009 mzugec@suse.cz
- fixed help text (bnc#529149)
- 2.18.5
* Mon Oct 19 2009 mzugec@suse.cz
- error messages more verbose for dump module (bnc#525440)
- 2.18.4
* Wed Sep 30 2009 mzugec@suse.cz
- L3: configure diag for dasd disks (bnc#530411)
- 2.18.3
* Fri Aug  7 2009 mzugec@suse.cz
- stretch zfcp dialog (bnc#524128)
- 2.18.2
* Fri Jul 10 2009 coolo@novell.com
- use the right template to work with automake 1.11
- 2.18.1
* Tue Jan 27 2009 mzugec@suse.cz
- descriptions for return values  (bnc#446998)
- 2.18.0
* Thu Oct 16 2008 ro@suse.de
- temporary workaround for yast2-schema:
  require s390-tools only on s390 and s390x
- 2.17.0
* Thu Sep 11 2008 jsrain@suse.cz
- merged texts from proofread
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Tue Jan 15 2008 jsrain@suse.cz
- added missing HTML tag (#351063)
* Fri Nov 30 2007 jsrain@suse.cz
- merged texts from proofread
* Fri Oct 19 2007 mzugec@suse.de
- allow to select zfcp WWPN and LUN manually (#332690)
- 2.16.0
* Thu Aug 30 2007 mzugec@suse.cz
- zfcp discovery in add dialog (fate#300869)
- 2.15.1
* Wed Mar 14 2007 mvidner@suse.cz
- Tell yast2-schema about our schema pieces (#242148).
* Mon Mar  5 2007 jsrain@suse.cz
- removed ExclusiveArch (#242148)
* Tue Feb 20 2007 jsrain@suse.cz
- packed missing schema files for AutoYaST (#242148)
- 2.15.0
* Thu Jan 18 2007 jsrain@suse.cz
- added _proposal clients for DASD and zFCP (#160399)
* Mon Nov  6 2006 locilka@suse.cz
- Call /sbin/zfcp_disk_configure always with 16-digit hex numbers
  (#205503).
- 2.13.16
* Fri Jun  2 2006 jsrain@suse.cz
- call mkinitd and zipl after disk activation in running system in
  order to have the disks activated also after reboot (#181085)
- 2.13.15
* Tue May 23 2006 jsrain@suse.cz
- updated error messages for ZFCP disk activation (#159552)
- 2.13.14
* Thu May 18 2006 mskibbe@suse.de
- Bug #155407 - Yast: Installation doesn't recognize partition on FBA VDISK
* Wed May 10 2006 ihno@use.de
- Write config values in correct order and activate XPRAM (#161352)
- Correct the use of the force-option. (#161363)
- 2.13.13
* Thu May  4 2006 locilka@suse.cz
- merged texts from proofreading
* Wed Apr 26 2006 jsrain@suse.de
- fixed reporting errors when activating a zFCP disk, enhanced
  help texts (#159552)
- 2.13.12
* Tue Apr 25 2006 jsrain@suse.de
- fixed activating of zFCP disks (#159555) (hare)
- 2.13.11
* Mon Apr 24 2006 ihno@suse.de
- fixed update of sysconfig-file (#161352)
- added force option to handle XPRAM which contains
  valid data. (#161363)
* Thu Apr 20 2006 ug@suse.de
- Fix ZFCP disk display (#159555 - LTC22544)
- Display and filter DASD on lcss 1 correctly
  (#152915 - LTC21934)
- 2.13.9
* Wed Apr 19 2006 ug@suse.de
- fixed some cloning stuff for DASD and ZFCP for
  autoyast
- 2.13.8
* Thu Mar 23 2006 locilka@suse.cz
- Replacing UI::Glyph(`CheckMark) with _("Yes") in UI (#145602)
- 2.13.7
* Fri Mar 17 2006 jsrain@suse.de
- allow DASD and zFCP disks configuration clonning (#153378)
- fixed displaying dump devices (#149978)
- 2.13.6
* Fri Mar 10 2006 locilka@suse.cz
- merged texts from proofreading
- 2.13.5
* Wed Mar  8 2006 jsrain@suse.de
- fixed adding zFCP disks (#151832)
- adapted BuildRequires
- 2.13.4
* Tue Feb 21 2006 jsrain@suse.de
- fixed creating dump device (#148661)
- 2.13.3
* Sat Feb 18 2006 ihno@suse.de
- Add Warning message for adding SAN-devices (Feature 300437)
* Thu Feb  9 2006 ihno@suse.de
- initial version of XPRAM
* Mon Jan 23 2006 jsrain@suse.cz
- fixed reading DASD disks (#144298)
- 2.13.1
* Wed Jan 11 2006 jsrain@suse.cz
- added clients to be called during installation (keep the left
  progress steps)
- 2.13.0
* Wed Oct  5 2005 jsrain@suse.cz
- added filtering to the zFCP disks dialog (#81867)
* Mon Oct  3 2005 jsrain@suse.cz
- display zFCP LUN as 16-digit hexa number (#118430)
- allow to keep the the DASD label when formatting (#57598)
* Tue Apr 19 2005 jsrain@suse.cz
- added preliminary support for dump devices configuration
* Thu Nov 18 2004 jsrain@suse.cz
- using dasdview to detect if a DASD disk is formatted (#42986)
* Fri Nov  5 2004 jsrain@suse.cz
- fixed problems when formatting >26 DASDs (#47699)
* Wed Oct 27 2004 jsrain@suse.cz
- adapted to new Mode:: interface
- 2.11.1
* Mon Oct 11 2004 jsrain@suse.cz
- adapted to new Arch:: interface
* Mon Sep  6 2004 jsrain@suse.cz
- ask for confirmation before formatting the DASD disks (#44376)
* Fri Sep  3 2004 jsrain@suse.cz
- added GetModified and SetModified functions to _auto clients
* Tue May  4 2004 jsrain@suse.cz
- merged texts from proofreading
- 2.9.5
* Mon May  3 2004 jsrain@suse.cz
- added autoinstallation support for DASD disks (#39806)
- displaying all required information for DASD disks (#39806)
- allow to set the DIAG mode on 31-bit S390 (#39806)
- 2.9.4
* Thu Apr 29 2004 jsrain@suse.cz
- activate zfcp adapter before activating any disk of it (#39339)
- offer DASD disks setup on mixed (DASD+ZFCP) system (#39338)
- added AI support for ZFCP disks
- added help texts
- 2.9.3
* Fri Apr  2 2004 jsrain@suse.de
- changed license to GPL
- 2.9.2
* Wed Mar 17 2004 jsrain@suse.cz
- added comments for translators
* Fri Mar 12 2004 jsrain@suse.de
- added support for DASD disks formatting
- 2.9.1
* Thu Mar 11 2004 jsrain@suse.de
- fixed detection of unconfigured DASD disks
* Wed Mar 10 2004 jsrain@suse.de
- added checking of DASD-only/zFCP-only/mixed system
- removed filter support for zFCP disks
- fixed .spec file (use ExclusiveArch)
- fixed parameters of dasd_configure script
- better defaults for new ZFCP disk, combo box for channels
- adapted to changed structure of hwinfo's output
* Mon Mar  8 2004 jsrain@suse.de
- initial version
- 2.9.0
